==> zio-aws-clouddirectory_3-5.17.123.2-sources.jar: zio/aws/clouddirectory/model/ListIncomingTypedLinksRequest.scala <==
package zio.aws.clouddirectory.model
import java.lang.Integer
import zio.aws.clouddirectory.model.primitives.{NumberResults, NextToken, Arn}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListIncomingTypedLinksRequest(
    directoryArn: Arn,
    objectReference: zio.aws.clouddirectory.model.ObjectReference,
    filterAttributeRanges: Option[
      Iterable[zio.aws.clouddirectory.model.TypedLinkAttributeRange]
    ] = None,
    filterTypedLink: Option[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName
    ] = None,
    nextToken: Option[NextToken] = None,
    maxResults: Option[NumberResults] = None,
    consistencyLevel: Option[zio.aws.clouddirectory.model.ConsistencyLevel] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.clouddirectory.model.ListIncomingTypedLinksRequest = {
    import ListIncomingTypedLinksRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.clouddirectory.model.ListIncomingTypedLinksRequest
      .builder()
      .directoryArn(Arn.unwrap(directoryArn): java.lang.String)
      .objectReference(objectReference.buildAwsValue())
      .optionallyWith(
        filterAttributeRanges.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filterAttributeRanges)
      .optionallyWith(filterTypedLink.map(value => value.buildAwsValue()))(
        _.filterTypedLink
      )
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => NumberResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(consistencyLevel.map(value => value.unwrap))(
        _.consistencyLevel
      )
      .build()
  }
  def asReadOnly
      : zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest.ReadOnly =
    zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest
      .wrap(buildAwsValue())
}
object ListIncomingTypedLinksRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.clouddirectory.model.ListIncomingTypedLinksRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest =
      zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest(
        directoryArn,
        objectReference.asEditable,
        filterAttributeRanges.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        filterTypedLink.map(value => value.asEditable),
        nextToken.map(value => value),
        maxResults.map(value => value),
        consistencyLevel.map(value => value)
      )
    def directoryArn: Arn
    def objectReference: zio.aws.clouddirectory.model.ObjectReference.ReadOnly
    def filterAttributeRanges: Option[
      List[zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly]
    ]
    def filterTypedLink: Option[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ]
    def nextToken: Option[NextToken]
    def maxResults: Option[NumberResults]
    def consistencyLevel: Option[zio.aws.clouddirectory.model.ConsistencyLevel]
    def getDirectoryArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(directoryArn)
    def getObjectReference: ZIO[
      Any,
      Nothing,
      zio.aws.clouddirectory.model.ObjectReference.ReadOnly
    ] = ZIO.succeed(objectReference)
    def getFilterAttributeRanges: ZIO[Any, AwsError, List[
      zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly
    ]] =
      AwsError.unwrapOptionField("filterAttributeRanges", filterAttributeRanges)
    def getFilterTypedLink: ZIO[
      Any,
      AwsError,
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ] = AwsError.unwrapOptionField("filterTypedLink", filterTypedLink)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, NumberResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getConsistencyLevel
        : ZIO[Any, AwsError, zio.aws.clouddirectory.model.ConsistencyLevel] =
      AwsError.unwrapOptionField("consistencyLevel", consistencyLevel)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.clouddirectory.model.ListIncomingTypedLinksRequest
  ) extends zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest.ReadOnly {
    override val directoryArn: Arn =
      zio.aws.clouddirectory.model.primitives.Arn(impl.directoryArn())
    override val objectReference
        : zio.aws.clouddirectory.model.ObjectReference.ReadOnly =
      zio.aws.clouddirectory.model.ObjectReference.wrap(impl.objectReference())
    override val filterAttributeRanges: Option[
      List[zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly]
    ] = scala
      .Option(impl.filterAttributeRanges())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.clouddirectory.model.TypedLinkAttributeRange.wrap(item)
        }.toList
      )
    override val filterTypedLink: Option[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ] = scala
      .Option(impl.filterTypedLink())
      .map(value =>
        zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.wrap(value)
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.clouddirectory.model.primitives.NextToken(value))
    override val maxResults: Option[NumberResults] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.clouddirectory.model.primitives.NumberResults(value)
      )
    override val consistencyLevel
        : Option[zio.aws.clouddirectory.model.ConsistencyLevel] = scala
      .Option(impl.consistencyLevel())
      .map(value => zio.aws.clouddirectory.model.ConsistencyLevel.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.clouddirectory.model.ListIncomingTypedLinksRequest
  ): zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-clouddirectory_3-5.17.265.1-sources.jar: zio/aws/clouddirectory/model/ListIncomingTypedLinksRequest.scala <==
package zio.aws.clouddirectory.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.clouddirectory.model.primitives.{NumberResults, NextToken, Arn}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListIncomingTypedLinksRequest(
    directoryArn: Arn,
    objectReference: zio.aws.clouddirectory.model.ObjectReference,
    filterAttributeRanges: Optional[
      Iterable[zio.aws.clouddirectory.model.TypedLinkAttributeRange]
    ] = Optional.Absent,
    filterTypedLink: Optional[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[NumberResults] = Optional.Absent,
    consistencyLevel: Optional[zio.aws.clouddirectory.model.ConsistencyLevel] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.clouddirectory.model.ListIncomingTypedLinksRequest = {
    import ListIncomingTypedLinksRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.clouddirectory.model.ListIncomingTypedLinksRequest
      .builder()
      .directoryArn(Arn.unwrap(directoryArn): java.lang.String)
      .objectReference(objectReference.buildAwsValue())
      .optionallyWith(
        filterAttributeRanges.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filterAttributeRanges)
      .optionallyWith(filterTypedLink.map(value => value.buildAwsValue()))(
        _.filterTypedLink
      )
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => NumberResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(consistencyLevel.map(value => value.unwrap))(
        _.consistencyLevel
      )
      .build()
  }
  def asReadOnly
      : zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest.ReadOnly =
    zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest
      .wrap(buildAwsValue())
}
object ListIncomingTypedLinksRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.clouddirectory.model.ListIncomingTypedLinksRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest =
      zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest(
        directoryArn,
        objectReference.asEditable,
        filterAttributeRanges.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        filterTypedLink.map(value => value.asEditable),
        nextToken.map(value => value),
        maxResults.map(value => value),
        consistencyLevel.map(value => value)
      )
    def directoryArn: Arn
    def objectReference: zio.aws.clouddirectory.model.ObjectReference.ReadOnly
    def filterAttributeRanges: Optional[
      List[zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly]
    ]
    def filterTypedLink: Optional[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ]
    def nextToken: Optional[NextToken]
    def maxResults: Optional[NumberResults]
    def consistencyLevel
        : Optional[zio.aws.clouddirectory.model.ConsistencyLevel]
    def getDirectoryArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(directoryArn)
    def getObjectReference: ZIO[
      Any,
      Nothing,
      zio.aws.clouddirectory.model.ObjectReference.ReadOnly
    ] = ZIO.succeed(objectReference)
    def getFilterAttributeRanges: ZIO[Any, AwsError, List[
      zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly
    ]] =
      AwsError.unwrapOptionField("filterAttributeRanges", filterAttributeRanges)
    def getFilterTypedLink: ZIO[
      Any,
      AwsError,
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ] = AwsError.unwrapOptionField("filterTypedLink", filterTypedLink)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, NumberResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getConsistencyLevel
        : ZIO[Any, AwsError, zio.aws.clouddirectory.model.ConsistencyLevel] =
      AwsError.unwrapOptionField("consistencyLevel", consistencyLevel)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.clouddirectory.model.ListIncomingTypedLinksRequest
  ) extends zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest.ReadOnly {
    override val directoryArn: Arn =
      zio.aws.clouddirectory.model.primitives.Arn(impl.directoryArn())
    override val objectReference
        : zio.aws.clouddirectory.model.ObjectReference.ReadOnly =
      zio.aws.clouddirectory.model.ObjectReference.wrap(impl.objectReference())
    override val filterAttributeRanges: Optional[
      List[zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.filterAttributeRanges())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.clouddirectory.model.TypedLinkAttributeRange.wrap(item)
        }.toList
      )
    override val filterTypedLink: Optional[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.filterTypedLink())
      .map(value =>
        zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.wrap(value)
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.clouddirectory.model.primitives.NextToken(value))
    override val maxResults: Optional[NumberResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.clouddirectory.model.primitives.NumberResults(value)
      )
    override val consistencyLevel
        : Optional[zio.aws.clouddirectory.model.ConsistencyLevel] =
      zio.aws.core.internal
        .optionalFromNullable(impl.consistencyLevel())
        .map(value => zio.aws.clouddirectory.model.ConsistencyLevel.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.clouddirectory.model.ListIncomingTypedLinksRequest
  ): zio.aws.clouddirectory.model.ListIncomingTypedLinksRequest.ReadOnly =
    new Wrapper(impl)
}
